# dbf2sql

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Overview

DBF2SQL is a Python CLI program that offers an interface to Convert DBF files in SQL Server tables

## Pre-requirements

- [Download ODBC Driver for SQL Server](https://docs.microsoft.com/es-es/sql/connect/odbc/download-odbc-driver-for-sql-server?view=sql-server-ver15)

## License

This library is published under the terms of the MIT License. Please check the LICENSE file for more details.
